Commit Diff


commit - 1e692e5890c2a5dedf4864f5522b148734851cde
commit + c79fa28a66110b5a5f938b283c7608e749473efc
blob - e5e59de7e9a6c8ebe275bdbae52feedb1b24eb3a
blob + 7aa2953703609833d15bf0f03a58a83928932a24
--- src/ngircd/conn.c
+++ src/ngircd/conn.c
@@ -16,7 +16,7 @@
 
 #include "portab.h"
 
-static char UNUSED id[] = "$Id: conn.c,v 1.137 2004/05/30 16:25:51 alex Exp $";
+static char UNUSED id[] = "$Id: conn.c,v 1.138 2004/10/04 23:09:04 alex Exp $";
 
 #include "imp.h"
 #include <assert.h>
@@ -964,9 +964,9 @@ New_Connection( INT Sock )
 	cnt = Count_Connections( new_addr );
 	if(( Conf_MaxConnectionsIP > 0 ) && ( cnt >= Conf_MaxConnectionsIP ))
 	{
-		/* Access denied, too many connections from this IP! */
-		Log( LOG_ERR, "Refused connection from %s: too may connections (%ld) from this IP!", inet_ntoa( new_addr.sin_addr ), cnt);
-		Simple_Message( new_sock, "ERROR :Connection refused, too many connections from your IP!" );
+		/* Access denied, too many connections from this IP address! */
+		Log( LOG_ERR, "Refused connection from %s: too may connections (%ld) from this IP address!", inet_ntoa( new_addr.sin_addr ), cnt);
+		Simple_Message( new_sock, "ERROR :Connection refused, too many connections from your IP address!" );
 		close( new_sock );
 		return;
 	}